```{toctree}
:maxdepth: 2
:titlesonly:
:caption: General
:hidden:

Readme <misc/readme_link>
User Guide <userguide/userguide>
Examples <examples/examples>
Contribute <misc/contributing_link>
```

```{include} ../README.md
:relative-docs: docs/
```

# Package documentation
```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:
   :caption: Package

   baybe
```

```{toctree}
    :maxdepth: 2
    :titlesonly:
    :caption: Misc
    :hidden:

    Known Issues <known_issues>
    Changelog <misc/changelog_link>
    Github <https://github.com/emdgroup/baybe/>
    Contributors <misc/contributors_link>
    License <misc/license_link>
```

# Indices and Tables

- {ref}`modindex`
